@@ -3,16 +3,17 @@ This example is the demonstration of getting player health with toy-arms interna
 Make sure that you inject this image to csgo.exe.
 also, the offset of DW_LOCAL_PLAYER works as of the day i wrote this but it might not be up to date in your case.
 */
-use toy_arms::{create_entrypoint, cast, VirtualKeyCode};
-use toy_arms::Module;
-use toy_arms_derive::GameObject;
 use toy_arms::GameObject;
+use toy_arms::Module;
+use toy_arms::{cast, create_entrypoint, VirtualKeyCode};
+use toy_arms_derive::GameObject;
 
 create_entrypoint!(hack_main_thread);
 
+// This macro provides from_raw() func that ensures the base address is not null.
 #[derive(GameObject)]
 struct LocalPlayer {
-    pointer: *const usize, // Denotes the base address of LocalPlayer
+    pointer: *const usize, // Denote the base address of LocalPlayer to use it later in get_health() function.
 }
 
 impl LocalPlayer {
@@ -22,20 +23,19 @@ impl LocalPlayer {
 }
 
 // This offset has to be up to date.
-const DW_LOCAL_PLAYER: i32 = 0xDA545C;
+const DW_LOCAL_PLAYER: i32 = 0xDB35EC;
 
 fn hack_main_thread() {
-    let memory = Module::from_module_name("client.dll");
+    let module = Module::from_module_name("client.dll").unwrap();
     unsafe {
         //let dw_local_player = memory.read_mut::<LocalPlayer>(0xDA244C);
         loop {
-            if let Some(i) = LocalPlayer::from_raw(memory.read_mut(DW_LOCAL_PLAYER)) {
+            if let Some(i) = LocalPlayer::from_raw(module.read(DW_LOCAL_PLAYER)) {
                 println!("health = {:?}", (*i).get_health());
             };
-            if toy_arms::detect_keydown(VirtualKeyCode::VK_INSERT) {
+            if toy_arms::detect_keypress(VirtualKeyCode::VK_INSERT) {
                 break;
             }
         }
     }
-
-}
\ No newline at end of file
+}
