@@ -4,7 +4,8 @@ This code gets module handle and function address of the func called MessageBoxA
 Then read the value called dwForceAttack and overwrite it to make player shoot.
 The offset DW_FORCE_ATTACK works as of the day i wrote this but it might not be up to date in your case.
 */
-use toy_arms::{detect_keydown, get_module_function_address, get_module_handle, HMODULE, Module, VirtualKeyCode};
+
+use toy_arms::{detect_keypress, detect_keydown, get_module_function_address, get_module_handle, HMODULE, Module, VirtualKeyCode};
 use toy_arms::cast;
 
 toy_arms::create_entrypoint!(hack_main_thread);
@@ -23,17 +24,23 @@ fn hack_main_thread() {
         println!("function address = {:?}", function_address);
     }
 
-    let memory = Module::from_module_name("client.dll").unwrap();
+    let module = Module::from_module_name("client.dll").unwrap();
 
     let shoot_flag = cast!(mut module_handle as usize + DW_FORCE_ATTACK, u8);
+
     loop {
         unsafe {
             // Auto shoot
             *shoot_flag = 5u8;
         }
         // To exit this hack loop when you input INSEERT KEY
-        if detect_keydown(VirtualKeyCode::VK_INSERT) {
-            break
+        if detect_keypress(VirtualKeyCode::VK_INSERT) {
+            break;
+        }
+
+        // just flexing this neat function xd.
+        if detect_keydown!(VirtualKeyCode::VK_HOME) {
+            println!("HOME is both pressed");
         }
     }
 }
